.. Copyright 2015 University of York
   Author: Aaron Ecay

Weihnachtsgurke search tool
===========================

This document contains the user’s manual for the Weihnachtsgurke search
tool for the PYCCLE-TCP corpus.

.. TODO: link to corpus webpage.

It is named for the pseudo-German `Christmas pickle hunt
<https://en.wikipedia.org/wiki/Christmas_pickle>`_.

The corpus and tool have been developed by `Aaron Ecay
<http://aaronecay.com>`_ under the auspices of the `Centre for
Linguistic History and Diversity
<http://www.york.ac.uk/language/research/centres/clhd/>`_ at the
University of York’s `Department of Language and Linguistic Science
<http://www.york.ac.uk/language/>`_.

The corpus is tagged with the `PPCEME tagset
<http://www.ling.upenn.edu/histcorpora/annotation/index.html>`_.
Familiarity with it will be helpful in understanding this doucment.

Contents:

.. toctree::
   :maxdepth: 2

   install
   commandline
   searchguide
   output


.. only:: html

   Indices and tables
   ==================

   ..
      * :ref:`genindex`
      * :ref:`modindex`

   * :ref:`search`
